library splash_screen_view;

import 'package:flutter/cupertino.dart';
import 'package:flutter/material.dart';

import 'colorize.dart';

/// The [Widget] name of target screen after completion of splash screen milliseconds.
Widget _home;

///  [String] Asset path of your logo image.
String _imageSrc;

///  [String] that would be displayed on below logo.
String _text;

/// Select [TextType] of your text.
///
/// By default it is NormalText.
TextType _textType;

/// Gives [TextStyle] to the text strings.
TextStyle _textStyle;

/// The [Duration] of the delay between the apparition of each characters
///
/// By default it is set to 3000 milliseconds.
int _duration = 3000;

///  [int] Size of your image logo.
///
/// By default it is set to 200.
int _logoSize = 200;

///  [Color] Background Color of your splash screen.
/// By default it is set to white.
Color _backgroundColor = Colors.white;

/// Set the colors for the gradient animation of the text.
///
/// The [List] should contain at least two values of [Color] in it.
List<Color> _colors;

enum TextType {
  ColorizeAnimationText,
  NormalText,
}

class SplashScreenView extends StatefulWidget {
  SplashScreenView(
      {@required String imageSrc,
      @required Widget home,
      @required int duration,
      int imageSize,
      textStyle,
      colors,
      textType,
      Color backgroundColor,
      String text}) {
    assert(duration != null);
    assert(home != null);
    assert(imageSrc != null);

    _imageSrc = imageSrc;
    _home = home;
    _duration = duration;
    _colors = colors;
    _text = text;
    _textStyle = textStyle;
    _logoSize = imageSize;
    _backgroundColor = backgroundColor;
    _textType = textType;
  }

  @override
  _SplashScreenViewState createState() => _SplashScreenViewState();
}

class _SplashScreenViewState extends State<SplashScreenView>
    with SingleTickerProviderStateMixin {
  AnimationController _animationController;
  Animation _animation;

  @override
  void initState() {
    super.initState();
    if (_duration < 1000) _duration = 3000;
    _animationController = new AnimationController(
        vsync: this, duration: Duration(milliseconds: 1000));
    _animation = Tween(begin: 0.0, end: 1.0).animate(CurvedAnimation(
        parent: _animationController, curve: Curves.easeInCirc));
    _animationController.forward();

    Future.delayed(Duration(milliseconds: _duration)).then((value) {
      Navigator.of(context).pushReplacement(
          CupertinoPageRoute(builder: (BuildContext context) => _home));
    });
  }

  @override
  void dispose() {
    super.dispose();
    _animationController.reset();
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      backgroundColor: _backgroundColor,
      body: Container(
        width: MediaQuery.of(context).size.width,
        height: MediaQuery.of(context).size.height,
        child: FadeTransition(
          opacity: _animation,
          child: Column(
            mainAxisAlignment: MainAxisAlignment.center,
            crossAxisAlignment: CrossAxisAlignment.center,
            children: <Widget>[
              Image.asset(
                _imageSrc,
                height: _logoSize.toDouble(),
              ),
              Padding(
                padding: const EdgeInsets.all(10),
                child: getTextWidget(),
              )
            ],
          ),
        ),
      ),
    );
  }

  Widget getTextWidget() {
    switch (_textType) {
      case TextType.ColorizeAnimationText:
        return ColorizeAnimatedTextKit(
          text: _text,
          speed: Duration(milliseconds: 1000),
          textStyle:
              (_textStyle != null) ? _textStyle : TextStyle(fontSize: 20.0),
          colors: _colors,
        );
      case TextType.NormalText:
        return Text(
          _text,
          style: (_textStyle != null) ? _textStyle : TextStyle(fontSize: 20.0),
        );
      default:
        return Text(
          _text,
          style: (_textStyle != null) ? _textStyle : TextStyle(fontSize: 20.0),
        );
    }
  }
}
